@@ -4,7 +4,7 @@ use 5.010;
 use strict;
 use warnings;
 
-our $VERSION = '0.91';
+our $VERSION = '0.92';
 
 use utf8;
 use Encode;
@@ -153,12 +153,13 @@ sub new {
         use strict 'refs';
     }
 
-    $class->autosave(0);
+    $class->auto_save(0);
 
     return bless $param || {}, $class;
 }
 
-sub autoload {
+
+sub auto_load {
     my ($class) = @_;
 
     my @class_name_parts = split q/::/, $class;
@@ -185,7 +186,7 @@ sub autoload {
     my $primary_key = ($primary_key_data) ? $primary_key_data->{COLUMN_NAME} : undef;
 
     # 3. Foreign keys
-    # ...
+    # TODO
 
     $class->table_name($table_name) if $table_name;
     $class->primary_key($primary_key) if $primary_key;
@@ -193,8 +194,8 @@ sub autoload {
 }
 
 sub load_info {
-    carp '[DEPRECATED] This method is deprecated and will be remowed in the feature. Use method "autoload" instead.';
-    $_[0]->autoload;
+    carp '[DEPRECATED] This method is deprecated and will be remowed in the feature. Use method "auto_load" instead.';
+    $_[0]->auto_load;
 }
 
 sub _mk_accessors {
@@ -508,7 +509,7 @@ sub _table_name {
     return $table_name;
 }
 
-sub autosave {
+sub auto_save {
     my ($class, $is_on) = @_;
 
     $is_on = 1 if not defined $is_on;
@@ -517,8 +518,8 @@ sub autosave {
 }
 
 sub use_smart_saving {
-    carp '[DEPRECATED] Method "use_smart_saving" is deprecated and will be removed in the future. Please, use "authosave" method insted.';
-    $_[0]->autosave;
+    carp '[DEPRECATED] Method "use_smart_saving" is deprecated and will be removed in the future. Please, use "auto_save" method insted.';
+    $_[0]->auto_save;
 }
 
 sub relations {
@@ -764,12 +765,13 @@ sub to_hash {
     my ($self, $param) = @_;
 
     my $field_names = $self->_get_columns;
+    push @$field_names, keys %{ $self->_get_mixins } if $self->can('_get_mixins');
     my $attrs = {};
 
     for my $field (@$field_names) {
         next if ref $field;
         if ( $param && $param->{only_defined_fields} ) {
-            $attrs->{$field} = $self->{$field} if $self->$field;
+            $attrs->{$field} = $self->{$field} if defined $self->$field;
         }
         else {
             $attrs->{$field} = $self->{$field};
@@ -841,6 +843,7 @@ sub select { ActiveRecord::Simple::Find->select(shift, @_) }
 
 sub _find_many_to_many { ActiveRecord::Simple::Find->_find_many_to_many(shift, @_) }
 
+sub DESTROY {}
 
 ### FIXME: this implementation is actually too slow, need much faster solution
 sub AUTOLOAD {
@@ -849,9 +852,9 @@ sub AUTOLOAD {
     my $sub = $AUTOLOAD; $sub =~ s/.*:://g;
     my $error = "Unknown method: $sub";
 
-    die "Undefined object for method $sub: must be not undef" unless $param;
+    croak "Undefined object for method $sub: must be not undef" unless $param;
 
-    die $error unless $self->can('_get_relations');
+    croak $error unless $self->can('_get_relations');
     my @many2manies;
     my $relations = $self->_get_relations;
 
@@ -878,7 +881,6 @@ sub AUTOLOAD {
     return $subclass->new(\%class_options);
 }
 
-
 ### Private
 
 
@@ -903,7 +905,7 @@ pattern. It's fast, very simple and very light.
     package MyModel:Person;
     use base 'ActiveRecord::Simple';
 
-    __PACKAGE__->autoload()
+    __PACKAGE__->auto_load()
 
     1;
 
@@ -1114,13 +1116,13 @@ Create an index and add it to the schema. Works only when method "fields" is usi
 Set name of the table. This method is required to use in the child (your model)
 classes.
 
-=head2 autoload
+=head2 auto_load
 
 Load table info using DBI methods: table_name, primary_key, foreign_key, columns
 
 =head2 load_info
 
-Same as "autoload". DEPRECATED.
+Same as "auto_load". DEPRECATED.
 
 =head2 belongs_to
 
@@ -1194,7 +1196,7 @@ just keep this simple schema in youre mind:
     my $single = Song->find({ type => 'single' })->fetch();
     my @photos = $single->photos->fetch();  # fetch all photos with pub_date = single.release_date
 
-=head2 autosave
+=head2 auto_save
 
 This method provides two features:
 
@@ -1204,11 +1206,11 @@ This method provides two features:
    2. Automatic save on object destroy (You don't need use "save()" method
       anymore).
 
-    __PACKAGE__->autosave;
+    __PACKAGE__->auto_save;
 
 =head2 use_smart_saving
 
-Same as "autosave". DEPRECATED.
+Same as "auto_save". DEPRECATED.
 
 =head2 find
 
@@ -1486,9 +1488,8 @@ This method uses as many fields as you want:
 
 Use chain "order_by" if you would like to order your data in different ways:
 
-    my @asc_ordered_fields = ('name', 'age');
-    my @desc_ordered_fields = ('zip', 'gender');
-    my @persons = Model->find->order_by(@asc_ordered_fields)->asc->order_by(@desc_ordered_fields)->desc->fetch;
+    my @persons = Model->find->order_by('name', 'age')->asc->order_by('zip')->desc->fetch;
+    # This is equal to ... ORDER BY name, age ASC, zip DESC;
 
 =head2 asc
 
