@@ -459,12 +459,13 @@ sub upload {
 sub next {
     my ($self) = @_;
 
-    if (!$self->{_objects}) {
-        my @objects = $self->fetch();
-        $self->{_objects} = \@objects;
-    }
+    $self->{prep_limit} = 1;
+    $self->{prep_offset} = 0 unless defined $self->{prep_offset};
+    my $result = $self->fetch;
 
-    return (scalar @{ $self->{_objects} } > 0 ) ? $self->_get_slice($self->{_objects}) : undef;
+    $self->{prep_offset} += 1;
+
+    return $result;
 }
 
 sub with {
